"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseInsertObjectOrList = void 0;
const column_node_js_1 = require("../operation-node/column-node.js");
const primitive_value_list_node_js_1 = require("../operation-node/primitive-value-list-node.js");
const value_list_node_js_1 = require("../operation-node/value-list-node.js");
const object_utils_js_1 = require("../util/object-utils.js");
const value_parser_js_1 = require("./value-parser.js");
const values_node_js_1 = require("../operation-node/values-node.js");
const complex_expression_parser_js_1 = require("./complex-expression-parser.js");
function parseInsertObjectOrList(ctx, args) {
    return parseInsertColumnsAndValues(ctx, Array.isArray(args) ? args : [args]);
}
exports.parseInsertObjectOrList = parseInsertObjectOrList;
function parseInsertColumnsAndValues(ctx, rows) {
    const columns = parseColumnNamesAndIndexes(rows);
    return [
        (0, object_utils_js_1.freeze)([...columns.keys()].map(column_node_js_1.ColumnNode.create)),
        values_node_js_1.ValuesNode.create(rows.map((row) => parseRowValues(ctx, row, columns))),
    ];
}
function parseColumnNamesAndIndexes(rows) {
    const columns = new Map();
    for (const row of rows) {
        const cols = Object.keys(row);
        for (const col of cols) {
            if (!columns.has(col) && row[col] !== undefined) {
                columns.set(col, columns.size);
            }
        }
    }
    return columns;
}
function parseRowValues(ctx, row, columns) {
    const rowColumns = Object.keys(row);
    const rowValues = new Array(columns.size).fill(null);
    for (const col of rowColumns) {
        const columnIdx = columns.get(col);
        const value = row[col];
        if (columnIdx !== undefined) {
            rowValues[columnIdx] = value;
        }
    }
    if (rowValues.some(complex_expression_parser_js_1.isComplexExpression)) {
        return value_list_node_js_1.ValueListNode.create(rowValues.map((it) => (0, value_parser_js_1.parseValueExpression)(ctx, it)));
    }
    return primitive_value_list_node_js_1.PrimitiveValueListNode.create(rowValues);
}
